==> quarkus-core-deployment-1.0.1.Final-sources.jar: io/quarkus/deployment/pkg/PackageConfig$$accessor.java <==
package io.quarkus.deployment.pkg;
public final class PackageConfig$$accessor {
    private PackageConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_type(Object __instance) {
        return ((PackageConfig)__instance).type;
    }
    @SuppressWarnings("unchecked")
    public static void set_type(Object __instance, Object type) {
        ((PackageConfig)__instance).type = (String)type;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_uberJar(Object __instance) {
        return ((PackageConfig)__instance).uberJar;
    }
    @SuppressWarnings("unchecked")
    public static void set_uberJar(Object __instance, boolean uberJar) {
        ((PackageConfig)__instance).uberJar = uberJar;
    }
    @SuppressWarnings("unchecked")
    public static Object get_mainClass(Object __instance) {
        return ((PackageConfig)__instance).mainClass;
    }
    @SuppressWarnings("unchecked")
    public static void set_mainClass(Object __instance, Object mainClass) {
        ((PackageConfig)__instance).mainClass = (String)mainClass;
    }
    @SuppressWarnings("unchecked")
    public static Object get_userConfiguredIgnoredEntries(Object __instance) {
        return ((PackageConfig)__instance).userConfiguredIgnoredEntries;
    }
    @SuppressWarnings("unchecked")
    public static void set_userConfiguredIgnoredEntries(Object __instance, Object userConfiguredIgnoredEntries) {
        ((PackageConfig)__instance).userConfiguredIgnoredEntries = (java.util.List<String>)userConfiguredIgnoredEntries;
    }
    @SuppressWarnings("unchecked")
    public static Object get_runnerSuffix(Object __instance) {
        return ((PackageConfig)__instance).runnerSuffix;
    }
    @SuppressWarnings("unchecked")
    public static void set_runnerSuffix(Object __instance, Object runnerSuffix) {
        ((PackageConfig)__instance).runnerSuffix = (String)runnerSuffix;
    }
    public static Object construct() {
        return new PackageConfig();
    }
}

==> quarkus-core-deployment-1.3.1.Final-sources.jar: io/quarkus/deployment/pkg/PackageConfig$$accessor.java <==
package io.quarkus.deployment.pkg;
public final class PackageConfig$$accessor {
    private PackageConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_type(Object __instance) {
        return ((PackageConfig)__instance).type;
    }
    @SuppressWarnings("unchecked")
    public static void set_type(Object __instance, Object type) {
        ((PackageConfig)__instance).type = (String)type;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_uberJar(Object __instance) {
        return ((PackageConfig)__instance).uberJar;
    }
    @SuppressWarnings("unchecked")
    public static void set_uberJar(Object __instance, boolean uberJar) {
        ((PackageConfig)__instance).uberJar = uberJar;
    }
    @SuppressWarnings("unchecked")
    public static Object get_manifest(Object __instance) {
        return ((PackageConfig)__instance).manifest;
    }
    @SuppressWarnings("unchecked")
    public static void set_manifest(Object __instance, Object manifest) {
        ((PackageConfig)__instance).manifest = (ManifestConfig)manifest;
    }
    @SuppressWarnings("unchecked")
    public static Object get_mainClass(Object __instance) {
        return ((PackageConfig)__instance).mainClass;
    }
    @SuppressWarnings("unchecked")
    public static void set_mainClass(Object __instance, Object mainClass) {
        ((PackageConfig)__instance).mainClass = (String)mainClass;
    }
    @SuppressWarnings("unchecked")
    public static Object get_userConfiguredIgnoredEntries(Object __instance) {
        return ((PackageConfig)__instance).userConfiguredIgnoredEntries;
    }
    @SuppressWarnings("unchecked")
    public static void set_userConfiguredIgnoredEntries(Object __instance, Object userConfiguredIgnoredEntries) {
        ((PackageConfig)__instance).userConfiguredIgnoredEntries = (java.util.Optional<java.util.List<String>>)userConfiguredIgnoredEntries;
    }
    @SuppressWarnings("unchecked")
    public static Object get_runnerSuffix(Object __instance) {
        return ((PackageConfig)__instance).runnerSuffix;
    }
    @SuppressWarnings("unchecked")
    public static void set_runnerSuffix(Object __instance, Object runnerSuffix) {
        ((PackageConfig)__instance).runnerSuffix = (String)runnerSuffix;
    }
    @SuppressWarnings("unchecked")
    public static Object get_outputDirectory(Object __instance) {
        return ((PackageConfig)__instance).outputDirectory;
    }
    @SuppressWarnings("unchecked")
    public static void set_outputDirectory(Object __instance, Object outputDirectory) {
        ((PackageConfig)__instance).outputDirectory = (java.util.Optional<String>)outputDirectory;
    }
    @SuppressWarnings("unchecked")
    public static Object get_outputName(Object __instance) {
        return ((PackageConfig)__instance).outputName;
    }
    @SuppressWarnings("unchecked")
    public static void set_outputName(Object __instance, Object outputName) {
        ((PackageConfig)__instance).outputName = (java.util.Optional<String>)outputName;
    }
    public static Object construct() {
        return new PackageConfig();
    }
}
